function [map_val]    = map_eval(Y_1,X_1,Y_2,X_2,beta_n,phi_n,C_aux,...
                                                      C_p_aux,beta_c,phi_c)
%-------------------------------------------------------------------------%
% [map_eval]   = map_eval(Y_1,X_1,Y_2,X_2,beta_n,phi_n,C_aux,...
%                                                     C_p_aux,beta_c,phi_c)
%
% This function evaluates the MAP objective function for the nonnegative 
% coupled CP model.
%
% The inputs are:
% 
% - Y_1,Y_2     : data blocks;
% - X_1,X_2     : models;
% - beta_n      : beta divergence index for the measurements;
% - phi_n       : dispersion parameters for the measurements;
% - C_aux,...   : coupled factors;
% - beta_c      : beta divergence index for the coupling;
% - phi_c       : dispersion of the coupling.
%
% The outputs are:
% 
% - map_val     : value of the MAP objective value.
%
% List of updates                 -     03/04/2015  -     Rodrigo Cabral
%                                       Creation of the file 
%-------------------------------------------------------------------------%

%-------------------------------Evalutaion--------------------------------%
map_val   =     (1/phi_n(1))*beta_div_eval(Y_1,X_1,beta_n(1))+...
                (1/phi_n(2))*beta_div_eval(Y_2,X_2,beta_n(2))+...
                (1/phi_c)*beta_div_eval(C_aux,C_p_aux,beta_c)+...
                +(beta_c/2)*sum(log(C_aux(:)));
%-------------------------------------------------------------------------%
end